/****************************************************************************
** Meta object code from reading C++ file 'main_window.hh'
**
** Created by: The Qt Meta Object Compiler version 68 (Qt 6.8.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "main_window.hh"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'main_window.hh' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 68
#error "This file was generated using the moc from 6.8.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace


#ifdef QT_MOC_HAS_STRINGDATA
static constexpr auto qt_meta_stringdata_ZN10MainWindowE = QtMocHelpers::stringData(
    "MainWindow",
    "import",
    "",
    "new_recipe",
    "edit",
    "collect_garbage",
    "about",
    "filter",
    "reset",
    "selected",
    "QModelIndex",
    "current",
    "previous",
    "titles_context_menu",
    "pos",
    "recipe_context_menu",
    "export_recipes",
    "delete_recipes",
    "preview",
    "print",
    "add_to_category",
    "remove_from_category",
    "render",
    "QPrinter*",
    "printer",
    "language_en",
    "language_de",
    "language_fr",
    "language_it",
    "language_nl",
    "language_sl",
    "open_converter",
    "remove_duplicates"
);
#else  // !QT_MOC_HAS_STRINGDATA
#error "qtmochelpers.h not found or too old."
#endif // !QT_MOC_HAS_STRINGDATA

Q_CONSTINIT static const uint qt_meta_data_ZN10MainWindowE[] = {

 // content:
      12,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags, initial metatype offsets
       1,    0,  164,    2, 0x0a,    1 /* Public */,
       3,    0,  165,    2, 0x0a,    2 /* Public */,
       4,    0,  166,    2, 0x0a,    3 /* Public */,
       5,    0,  167,    2, 0x0a,    4 /* Public */,
       6,    0,  168,    2, 0x0a,    5 /* Public */,
       7,    0,  169,    2, 0x0a,    6 /* Public */,
       8,    0,  170,    2, 0x0a,    7 /* Public */,
       9,    2,  171,    2, 0x0a,    8 /* Public */,
      13,    1,  176,    2, 0x0a,   11 /* Public */,
      15,    1,  179,    2, 0x0a,   13 /* Public */,
      16,    0,  182,    2, 0x0a,   15 /* Public */,
      17,    0,  183,    2, 0x0a,   16 /* Public */,
      18,    0,  184,    2, 0x0a,   17 /* Public */,
      19,    0,  185,    2, 0x0a,   18 /* Public */,
      20,    0,  186,    2, 0x0a,   19 /* Public */,
      21,    0,  187,    2, 0x0a,   20 /* Public */,
      22,    1,  188,    2, 0x0a,   21 /* Public */,
      25,    0,  191,    2, 0x0a,   23 /* Public */,
      26,    0,  192,    2, 0x0a,   24 /* Public */,
      27,    0,  193,    2, 0x0a,   25 /* Public */,
      28,    0,  194,    2, 0x0a,   26 /* Public */,
      29,    0,  195,    2, 0x0a,   27 /* Public */,
      30,    0,  196,    2, 0x0a,   28 /* Public */,
      31,    0,  197,    2, 0x0a,   29 /* Public */,
      32,    0,  198,    2, 0x0a,   30 /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 10,   11,   12,
    QMetaType::Void, QMetaType::QPoint,   14,
    QMetaType::Void, QMetaType::QPoint,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 23,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_ZN10MainWindowE.offsetsAndSizes,
    qt_meta_data_ZN10MainWindowE,
    qt_static_metacall,
    nullptr,
    qt_incomplete_metaTypeArray<qt_meta_tag_ZN10MainWindowE_t,
        // Q_OBJECT / Q_GADGET
        QtPrivate::TypeAndForceComplete<MainWindow, std::true_type>,
        // method 'import'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'new_recipe'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'edit'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'collect_garbage'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'about'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'filter'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'reset'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'selected'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        // method 'titles_context_menu'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QPoint &, std::false_type>,
        // method 'recipe_context_menu'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QPoint &, std::false_type>,
        // method 'export_recipes'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'delete_recipes'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'preview'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'print'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'add_to_category'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'remove_from_category'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'render'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<QPrinter *, std::false_type>,
        // method 'language_en'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'language_de'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'language_fr'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'language_it'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'language_nl'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'language_sl'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'open_converter'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'remove_duplicates'
        QtPrivate::TypeAndForceComplete<void, std::false_type>
    >,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->import(); break;
        case 1: _t->new_recipe(); break;
        case 2: _t->edit(); break;
        case 3: _t->collect_garbage(); break;
        case 4: _t->about(); break;
        case 5: _t->filter(); break;
        case 6: _t->reset(); break;
        case 7: _t->selected((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 8: _t->titles_context_menu((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 9: _t->recipe_context_menu((*reinterpret_cast< std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 10: _t->export_recipes(); break;
        case 11: _t->delete_recipes(); break;
        case 12: _t->preview(); break;
        case 13: _t->print(); break;
        case 14: _t->add_to_category(); break;
        case 15: _t->remove_from_category(); break;
        case 16: _t->render((*reinterpret_cast< std::add_pointer_t<QPrinter*>>(_a[1]))); break;
        case 17: _t->language_en(); break;
        case 18: _t->language_de(); break;
        case 19: _t->language_fr(); break;
        case 20: _t->language_it(); break;
        case 21: _t->language_nl(); break;
        case 22: _t->language_sl(); break;
        case 23: _t->open_converter(); break;
        case 24: _t->remove_duplicates(); break;
        default: ;
        }
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ZN10MainWindowE.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
